@@ -6,8 +6,6 @@
 ( cd opt/kde/share/doc/HTML/sv/kdm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kig ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kig ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kit ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/juk ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/juk ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpf ; rm -rf common )
@@ -94,6 +92,8 @@
 ( cd opt/kde/share/doc/HTML/sv/kandy ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcalc ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kdcop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kdcop ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kdesu ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcron ; rm -rf common )
@@ -128,6 +128,8 @@
 ( cd opt/kde/share/doc/HTML/sv/ksysv ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/ktron ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kttsd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kttsd ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kuser ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kuser ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kview ; rm -rf common )
@@ -180,6 +182,8 @@
 ( cd opt/kde/share/doc/HTML/sv/ksirtet ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/konquest ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/konquest ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/akregator ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/akregator ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kturtle ; rm -rf common )
@@ -230,6 +234,8 @@
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 9.png )
@@ -260,6 +266,8 @@
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop1.png )
@@ -272,8 +280,12 @@
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf 10.png )
@@ -290,6 +302,10 @@
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/sv/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf kde-localised.css.template )
@@ -300,6 +316,8 @@
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/sv/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/sv/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
+( cd opt/kde/share/doc/HTML/sv/multisynk ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/multisynk ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kdm ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kcontrol/smb ; rm -rf common )
@@ -524,14 +542,20 @@
 ( cd opt/kde/share/doc/HTML/sv/kommander ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kiconedit ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kmahjongg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kmahjongg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klettres ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/klettres ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kfouleggs ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kfouleggs ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/xsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/xsldbg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kghostview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kghostview ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/klickety ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/klickety ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
+( cd opt/kde/share/doc/HTML/sv/kfilereplace ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sv/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kleopatra ; rm -rf common )
@@ -540,8 +564,6 @@
 ( cd opt/kde/share/doc/HTML/sv/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kenolaba ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
-( cd opt/kde/share/doc/HTML/sv/kgpgcertmanager ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sv/kgpgcertmanager ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kwatchgnupg ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sv/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/sv/common common )
 ( cd opt/kde/share/doc/HTML/sv/kworldclock ; rm -rf common )
